@@ -4,9 +4,9 @@ from ostrich.stats_provider import StatsProvider
 from ostrich.timing import Timing
 
 class StatsCollection(StatsProvider):
-    def __init__(self):
-        self.counters = {}
-        self.timings = {}
+    def __init__(self, counters=None, timings=None):
+        self.counters = counters or {}
+        self.timings = timings or {}
         self.counters_lock = threading.Lock()
         self.timings_lock = threading.Lock()
     
